@@ -1,5 +1,5 @@
 # Copyright 2015 FUJITSU LIMITED
-# (C) Copyright 2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 # in compliance with the License. You may obtain a copy of the License at
@@ -35,14 +35,14 @@ class PostgresqlRepo(BaseRepo):
             log.exception('Pgsql connect failed %s', e)
             raise
 
-    def fetch_notification(self, alarm):
+    def fetch_notifications(self, alarm):
         try:
             if self._pgsql is None:
                 self._connect_to_pgsql()
             cur = self._pgsql.cursor()
             cur.execute(self._find_alarm_action_sql, (alarm['alarmDefinitionId'], alarm['newState']))
             for row in cur:
-                yield (row[1].lower(), row[0], row[2], row[3])
+                yield (row[0], row[1].lower(), row[2], row[3], row[4])
         except psycopg2.Error as e:
             log.exception("Couldn't fetch alarms actions %s", e)
             raise exc.DatabaseException(e)
@@ -59,3 +59,40 @@ class PostgresqlRepo(BaseRepo):
         except psycopg2.Error as e:
             log.exception("Couldn't fetch current alarm state %s", e)
             raise exc.DatabaseException(e)
+
+    def fetch_notification_method_types(self):
+        try:
+            if self._pgsql is None:
+                self._connect_to_pgsql()
+            cur = self._pgsql.cursor()
+            cur.execute(self._find_all_notification_types_sql)
+            for row in cur:
+                yield (row[0])
+        except psycopg2.Error as e:
+            log.exception("Couldn't fetch notification types %s", e)
+            raise exc.DatabaseException(e)
+
+    def insert_notification_method_types(self, notification_types):
+        try:
+            if self._pgsql is None:
+                self._connect_to_pgsql()
+            cur = self._pgsql.cursor()
+            cur.executemany(self._insert_notification_types_sql, notification_types)
+        except psycopg2.Error as e:
+            log.exception("Couldn't insert notification types %s", e)
+            raise exc.DatabaseException(e)
+
+    def get_notification(self, notification_id):
+        try:
+            if self._pgsql is None:
+                self._connect_to_pgsql()
+            cur = self._pgsql.cursor()
+            cur.execute(self._get_notification_sql, notification_id)
+            row = cur.fetchone()
+            if row is None:
+                return None
+            else:
+                return [row[0], row[1].lower(), row[2], row[3]]
+        except psycopg2.Error as e:
+            log.exception("Couldn't fetch the notification method %s", e)
+            raise exc.DatabaseException(e)
