@@ -1,4 +1,4 @@
-# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development Company LP
+# (C) Copyright 2014-2016 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -47,17 +47,24 @@ class TestNotificationProcessor(unittest.TestCase):
                              'timeout': 60,
                              'from_addr': 'hpcs.mon@hp.com'}
 
+        self.mysql_config = {'ssl': None,
+                             'host': 'mysql_host',
+                             'port': 'mysql_port',
+                             'user': 'mysql_user',
+                             'db': 'dbname',
+                             'passwd': 'mysql_passwd'}
+
     def tearDown(self):
         pass
 
     # ------------------------------------------------------------------------
     # Test helper functions
     # ------------------------------------------------------------------------
-
+    @mock.patch('pymysql.connect')
     @mock.patch('monasca_notification.processors.notification_processor.monascastatsd')
     @mock.patch('monasca_notification.types.notifiers.email_notifier.smtplib')
     @mock.patch('monasca_notification.processors.notification_processor.notifiers.log')
-    def _start_processor(self, notifications, mock_log, mock_smtp, mock_statsd):
+    def _start_processor(self, notifications, mock_log, mock_smtp, mock_statsd, mock_pymsql):
         """Start the processor with the proper mocks
         """
         # Since the log runs in another thread I can mock it directly, instead change the methods to put to a queue
@@ -68,6 +75,8 @@ class TestNotificationProcessor(unittest.TestCase):
 
         config = {}
         config["email"] = self.email_config
+        config["mysql"] = self.mysql_config
+        config["notification_types"] = {}
 
         processor = (notification_processor.NotificationProcessor(config))
         processor.send(notifications)
@@ -88,7 +97,7 @@ class TestNotificationProcessor(unittest.TestCase):
                       "timestamp": time.time(),
                       "metrics": metric}
 
-        notification = Notification('email', 0, 1, 'email notification', 'me@here.com', 0, 0, alarm_dict)
+        notification = Notification(0, 'email', 'email notification', 'me@here.com', 0, 0, alarm_dict)
 
         self._start_processor([notification])
 
@@ -102,7 +111,7 @@ class TestNotificationProcessor(unittest.TestCase):
         alarm_dict = {"tenantId": "0", "alarmId": "0", "alarmName": "test Alarm", "oldState": "OK", "newState": "ALARM",
                       "stateChangeReason": "I am alarming!", "timestamp": time.time(), "metrics": "cpu_util",
                       "severity": "LOW", "link": "http://some-place.com", "lifecycleState": "OPEN"}
-        invalid_notification = Notification('invalid', 0, 1, 'test notification', 'me@here.com', 0, 0, alarm_dict)
+        invalid_notification = Notification(0, 'invalid', 'test notification', 'me@here.com', 0, 0, alarm_dict)
 
         self._start_processor([invalid_notification])
 
